@@ -5,7 +5,7 @@ __author__ = "Garrett Bates"
 __copyright__ = "© Copyright 2020-2021, Tartan Solutions, Inc"
 __credits__ = ["Garrett Bates"]
 __license__ = "Apache 2.0"
-__version__ = "0.1.4"
+__version__ = "0.1.6"
 __maintainer__ = "Garrett Bates"
 __email__ = "garrett.bates@tartansolutions.com"
 __status__ = "Development"
@@ -50,9 +50,9 @@ class RMQConfig(NamedTuple):
     username: str
     password: str
     vhost: str
-    event_username: str
-    event_password: str
-    event_vhost: str
+    public_username: str
+    public_password: str
+    public_vhost: str
     hostname: str = "rabbit-rabbitmq-ha"
     port: int = 5679
 
@@ -64,20 +64,20 @@ class RedisConfig(NamedTuple):
 
 class RedisURLConfig(NamedTuple):
     """URLs for Redis connections."""
-    activity: str = "redis://redis-master/4"
-    analyze_cache: str = "redis://redis-master/6"
-    cron_jobs: str = "redis://redis-master/1"
-    cron_running_jobs: str = "redis://redis-master/2"
-    data_connection_cache: str = "redis://redis-master/11"
-    document_cache: str = "redis://redis-master/7"
-    hierarchy_cache: str = "redis://redis-master/10"
-    identity_cache: str = "redis://redis-master/8"
-    ipython_registry: str = "redis://redis-master/3"
-    oauth_cache: str = "redis://redis-master/9"
-    redis_scheduler: str = "redis://redis-master/13"
-    scopes_cache: str = "redis://redis-master/12"
-    session: str = "redis://redis-master/0"
-    transform_container_registry: str = "redis://redis-master/5"
+    activity: str = "redis://@redis-master/4"
+    analyze_cache: str = "redis://@redis-master/6"
+    cron_jobs: str = "redis://@redis-master/1"
+    cron_running_jobs: str = "redis://@redis-master/2"
+    data_connection_cache: str = "redis://@redis-master/11"
+    document_cache: str = "redis://@redis-master/7"
+    hierarchy_cache: str = "redis://@redis-master/10"
+    identity_cache: str = "redis://@redis-master/8"
+    ipython_registry: str = "redis://@redis-master/3"
+    oauth_cache: str = "redis://@redis-master/9"
+    redis_scheduler: str = "redis://@redis-master/13"
+    scopes_cache: str = "redis://@redis-master/12"
+    session: str = "redis://@redis-master/0"
+    transform_container_registry: str = "redis://@redis-master/5"
 
 
 class ServiceConfig(NamedTuple):
@@ -101,11 +101,6 @@ class PlaidConfig:
             # Leave exception unhandled. We don't want to start without a valid conf.
             self.cfg = yaml.safe_load(stream)
 
-    @property
-    def log_level(self):
-        """Default log level for workflow-monitor."""
-        return self.cfg.get('logLevel', 'INFO')
-
     @property
     def database(self) -> DatabaseConfig:
         db_config = self.cfg.get('database', {})
